const express = require("express");
const router = express.Router();
const multer = require("multer");
const { v4: uuidv4 } = require("uuid");
const path = require("path");

//Upload dokumenta u folder
const storage = multer.diskStorage({
  destination: (req, file, cb) => {
    cb(null, "./public/documents");
  },
  filename: (req, file, cb) => {
    cb(null, uuidv4() + path.extname(file.originalname));
  },
  encoding: "utf-8",
});

//middleware za provjeru admina
const checkAdmin = (req, res, next) => {
  if (!req.session.user) {
    res.redirect("/login");
  } else {
    next();
  }
};
router.use(checkAdmin);

const upload = multer({ storage: storage });

router.get(
  "/dashboard/:state",
  require("../controllers/admin/dashboardController")
);
router.get("/vrste/:state", require("../controllers/admin/vrsteController"));
router.get(
  "/vrste/delete/:id",
  require("../controllers/admin/deleteVrsteController")
);

router.get(
  "/oblasti/:state",
  require("../controllers/admin/oblastiController")
);
router.get(
  "/oblasti/delete/:id",
  require("../controllers/admin/deleteOblastiController")
);
router.get("/propisi", require("../controllers/admin/propisiController"));
router.get(
  "/propisi/delete/:id",
  require("../controllers/admin/propisiDeleteController")
);

router.get(
  "/propisi/edit/:id",
  require("../controllers/admin/propisiEditController")
);

router.get(
  "/deletePrilog/",
  require("../controllers/admin/deletePrilogController")
);

router.post(
  "/kreirajVrstu",
  require("../controllers/admin/kreirajVrstuController")
);

router.post(
  "/kreirajOblast",
  require("../controllers/admin/kreirajOblastController")
);
router.post(
  "/kreirajPropis",
  upload.array("dokument"),
  require("../controllers/admin/kreirajPropisController")
);

router.post(
  "/editPropis",
  upload.array("dokument"),
  require("../controllers/admin/editPropisController")
);

module.exports = router;
